# Generated by Django 3.1 on 2020-08-24 19:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sites', '0002_alter_domain_unique'),
        ('helpme', '0006_ticket_site'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='team',
            name='site',
        ),
        migrations.AddField(
            model_name='team',
            name='sites',
            field=models.ManyToManyField(default=1, to='sites.Site'),
        ),
    ]
