# Generated by Django 3.1 on 2020-08-24 17:50

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('sites', '0002_alter_domain_unique'),
        ('helpme', '0005_auto_20200821_2224'),
    ]

    operations = [
        migrations.AddField(
            model_name='ticket',
            name='site',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, to='sites.site'),
        ),
    ]
