# Generated by Django 3.1 on 2020-08-21 21:55

from django.db import migrations, models
import django.db.models.deletion
import multiselectfield.db.fields


class Migration(migrations.Migration):

    dependencies = [
        ('sites', '0002_alter_domain_unique'),
        ('helpme', '0003_auto_20200821_1949'),
    ]

    operations = [
        migrations.AddField(
            model_name='team',
            name='categories',
            field=multiselectfield.db.fields.MultiSelectField(choices=[(1, 'Comment'), (2, 'Sales'), (3, 'Help'), (4, 'Bug')], default=3, max_length=7),
        ),
        migrations.AddField(
            model_name='team',
            name='site',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, to='sites.site'),
        ),
    ]
