# Generated by Django 3.1 on 2020-08-21 22:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('helpme', '0004_auto_20200821_2155'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='ticket',
            name='team',
        ),
        migrations.AddField(
            model_name='ticket',
            name='teams',
            field=models.ManyToManyField(blank=True, related_name='support_tickets', to='helpme.Team'),
        ),
    ]
